@@ -10,6 +10,7 @@ import os
 
 import pytest
 
+import pptx
 from pptx.api import Presentation
 from pptx.opc.constants import CONTENT_TYPE as CT
 from pptx.parts.presentation import PresentationPart
@@ -29,9 +30,7 @@ class DescribePresentation(object):
     @pytest.fixture
     def call_fixture(self, Package_, prs_, prs_part_):
         path = os.path.abspath(
-            os.path.join(
-                os.path.split(__file__)[0], "../pptx/templates", "default.pptx"
-            )
+            os.path.join(os.path.split(pptx.__file__)[0], "templates", "default.pptx")
         )
         Package_.open.return_value.main_document_part = prs_part_
         prs_part_.content_type = CT.PML_PRESENTATION_MAIN
